
/***************************************************************************
 *   This file is part of Aspect, a simple PEC tool.                       *
 *                                                                         *
 *   Copyright (C) 2006-2007 by Wolfgang Hoffmann <woho@woho.de>           *
 *                                                                         *
 *   This program is free software, licensed under the GPL v2.             *
 *   See the file COPYING for more details.                                *
 ***************************************************************************/


#ifndef ASPECT_MCUCMD_H
#define ASPECT_MCUCMD_H


#include "data.h"

#include <QByteArray>
#include <QString>
#include <QTime>

class McuSerial;


class IMcuCmd
    {
public:
    virtual ~IMcuCmd() {};
private:
    virtual bool flush() const { return true; };
    virtual QByteArray command() const = 0;
    virtual int receive(const QByteArray &aAnswerFragment) = 0;
    virtual QString name() const = 0;
friend class McuSerial;
    };


class McuRawCommand
    {
public:
    bool mcuSend(McuSerial &rPort);
    void setCommand(const QByteArray &aCommand) { m_aCommand = aCommand; };
    QByteArray answer() const { return m_aAnswer; };
private:
    QByteArray m_aCommand;
    QByteArray m_aAnswer;
    };

class McuDataFirmware
    {
public:
    bool mcuGet(McuSerial &rPort);
    QString firmware() const { return m_qsFirmware; };
private:
    QString m_qsFirmware;
    };

class McuDataState
    {
public:
    bool mcuGet(McuSerial &rPort);
    QString backlash() const;
    QString guideRate() const;
    QString paddle8Rate() const;
    QString paddle16Rate() const;
    QString gotoRate() const;
    int orientation() const;
    int rotation() const;
    QString rotOrient() const;
    int trackingRate() const;
    int gearboxReduction() const;
    int wormRatio() const;
    int wormTeeth() const;
private:
    QByteArray m_aState;
    };

class McuDataPecState
    {
public:
    McuDataPecState();
    bool mcuGet(McuSerial &rPort);
    bool mcuSetPec(McuSerial &rPort);
    bool mcuSetIntelly(McuSerial &rPort);
    QString state() const;
    int pec() const;
    void setPec(bool bOn);
    bool intellyTrack() const;
    void setIntellyTrack(bool bOn);
    double wormPos() const;
    QTime time() const { return m_oTimeBeg; };
private:
    QByteArray m_aState;
    QTime m_oTimeBeg;
    //QTime m_oTimeEnd;
    bool m_bPec;
    bool m_bIntellyTrack;
    };

class McuDataPecTable
    {
public:
    McuDataPecTable();
    bool mcuGetFactor(McuSerial &rPort);
    bool mcuGetValue(McuSerial &rPort, int nRow);
    bool mcuSetFactor(McuSerial &rPort) const;
    bool mcuSetValue(McuSerial &rPort, int nRow) const;
    bool mcuSave(McuSerial &rPort) const;
    PecData data(PecData::Traversal eDirection) const;
    bool set(const PecData &oData);
private:
    static const int c_nRowNum = 256;
    int m_nFactor;
    PecSample::Val m_aeVal[c_nRowNum];
    };

class McuDataTracking
    {
public:
    enum Rate { off, sidereal, solar, lunar };
    McuDataTracking();
    bool mcuSet(McuSerial &rPort);
    Rate rate() const;
    void setRate(Rate eRate);
private:
    Rate m_eRate;
    };

#if 0
class McuDataGuiding
    {
public:
    enum Direction { north, south, east, west };
    enum Speed { guide_x2, move_x8, slew_x16 };
    enum RateSlow { x1_33, x1_66, x2 };
    enum RateFast { x4, x8, x16, x20, x27, x40 };
private:
    };

class McuDataGoto
    {
public:
private:
    };

#endif


#endif // ASPECT_MCUCMD_H

