
/*!
    \mainpage

    Aspect is a simple PEC tool

    \ref userdoc

    \ref changelog
*/

/*!
    \page userdoc Aspect User Documentation


    \section purpose Purpose

    Aspect was created to semi-automate the process of teaching PEC (periodic
    error correction) for Rajiva's
    <a href="http://eq6.update.rajiva.de/" target="_blank">EQ6/HEQ5 MCU Upgrade kit</a>
    and the
    <a href="http://littlefoot.rajiva.de/" target="_blank">LittleFoot</a>
    astronomical mount stepper controler.

    While still under development, it's already useful.


    \section prepare Preparations

    You need
    - a serial connection to the LittleFoot/MCU
    - Doug Dieter's
        <a href="http://www.kennaquhair.com/MCUControlPlus/" target="_blank">MCU Control Plus</a><br>
        Currently, you need a beta version that has the PEC logging feature
        in the video/autoguiding module. If you intend to help beta testing
        Aspect and MCU Control Plus, ask Doug for a Snapshot on the
        <a href="http://forum.rajiva.de/ target="_blank"">Support Forum</a>
    - a webcam that could be used for autoguiding with MCU Control Plus<br>
        you don't need a guiding scope, you can use your main optics for
        measuring
    - clear skies


    \section quickguide Quick Guide

    This is a minimal description of the workflow, you might want to read
    the more verbose \ref walkthrough first.

    - Set PEC off and measure PE for at least one cycle in MCU Control Plus
    - Generate a PEC table in Aspect:
        - tab \c MCU :
            - choose serial port
        - tab <tt>PE Raw Data</tt>:
            - import PE file
        - tab <tt>PE Processing</tt>:
            - set \c smoothing \c width to eliminate seeing and short jumps
            - play with \c drift so that cycles match as good as possible
            - set \c scale to \c -1 if PE doubles with PEC, i.e. PEC makes things
                worse instead of better
            - maybe set \c scale to <tt>+/- 1 / cos(decl)</tt> if guide star
                declination \c decl is non-null (I'm not sure if this is necessary
                or not)
        - tab <tt>PEC Table</tt>:
            - set \c PEC \c factor to \c 1 ; Aspect so far is testet with value \c 1 only
            - set \c Worm \c Wheel \c Teeth, \c Rotation and \c Hemisphere ; optionally
                query the first two from the MCU by pressing the \c Query button
            - leave \c PEC \c acceleration as is for now
            - press the <tt>Calculate PEC from PE</tt> button
            - play with the \c Graph \c Offset to see how well or bad PE and the
                generated PEC match; maybe switch away the \c Raw \c PE graph with
                the checkbox below the chart area
            - upload the PEC table to the MCU by pressing the \c Put button, or
                save it to a file with <tt>Save As</tt> and restore it with MCU Control Plus

    Optionally do a dry run to verify if the generated PEC table makes the MCU moves
    the worm as intended, to get the required position profile for compensating the PE:
    - in Aspect:
        - tab <tt>PEC Profile</tt>:
            - maybe adjust \c Polling \c Interval (a poll every 0.5 seconds work fine for me)
            - press \c Start <br>
                \b Attention: this sets tracking speed to Sidereal and switches off IntellyTrack.
            - let run for at least one cycle
            - press \c Stop
            - use \c Graph \c Drift to make the purple graph run into it's beginning at the
                end of the first cycle; all cycles should match then.
            - use \c Graph \c Offset to move the purple PEC Profile graph match the green PEC
                graph as good as possible
        - if peak-to-valley of purple and green graph differ, reiterate PEC generation:<br>
            tab <tt>PEC Table</tt>:
            - adjust \c PEC \c Acceleration such that green and purple graph span same amplitude
            - press the <tt>Calculate PEC from PE</tt> button
            - upload PEC table to MCU and do another PEC profile run

    Now verify how good/bad the generated PEC table works under the sky:
    - Set PEC to on and redo measuring PE for at least one cycle in MCU Control Plus
        (select a different PEC log file than before, as this is the result of PE correction now)
    - Load PEC log into aspect
        - drift-compensate, scale and smooth as above
        - the resulting red graph ideally should become a flat horizontal line; you
            can read the remaining PE in arcseconds from the left scale (peak-to-valley; absolute
            values are not relevant)


    \section walkthrough Walkthrough

    \todo Write this ...

*/

/*

    \section walkthrough Walkthrough

    \subsection walkthrough_aqui PE data aquisition

    First you need to measure the PE (periodical error) of your mount.

    Currently there are two import filters in Aspect:
    - <a href="http://www.astrosurf.org/buil/iris/lecon24_us.htm" target="_blank">IRIS</a>:<br>
        Proceed as described at the above link, at the last quarter of the page.
        This method has a major drawback, as there is no recording of the
        worm wheel positions corresponding to the measured error values.<br>
        This is deprecated.
    - <a href="http://www.kennaquhair.com/MCUControlPlus/">MCU Control Plus</a><br>
        Currently, you need a beta version that has the PEC logging feature
        in the video/autoguiding module, see \ref prepare. <br>
        This is the recommended way.

    \todo Describe data aquisition with MCU Control Plus


    \subsection walkthrough_mcu MCU Settings

    Now launch Aspect and start out at the \c MCU tab:
    \image html screenshot-tab-mcu-v0.3.png "Tab MCU Settings"

    Set the port to where the MCU is attached by choosing one entry from the
    \c Serial \c port dropdown or entering a portname into it (click on the text
    to edit). On Linux you can also enter a full device name, e.g. \c /dev/ttyS0

    Currently connection is opened only on demand, and closed immediately after
    finishing the particular communication (e.g. open port, get PEC table, close
    port). The toggle button \c Autoconnect is hardcoded permanently checked,
    an explicit connect/disconnect functionality might be implemented later.

    To check if the communication is ok, press the \c Refresh button to query
    the current settings.

    For debugging, you might manually enter a raw command into the \c Command
    textfield at the bottom, and press \c Send to submit it to the MCU. The
    resulting answer is shown in the \c Answer textfield.
    \b Warning: unless you know what you're doing, don't use this. This is a
    low level access into the MCU. You might screw up your settings if entering
    random commands here.


    \subsection walkthrough_peraw PE Raw Data Import

*/


/*!
    \page changelog Aspect Changelog

    \section v03 Aspect 0.3 (14 Jan 2007)

    - new features:
        - generate PEC tables
        - measure resulting PEC profile
        - added user documentation fragments
    - bugfixes:
        - write PEC table files with CR/LF as line terminator,
            otherwise MCU Control Plus can't read them
        - add timeouts at serial communication to avoid hanging the application
            if no LittleFoot/MCU is connected
        - fix default file paths to be common locations

    \section v02 Aspect 0.2 (06 Jan 2007)

    - new features:
        - import PE data from Doug Dieter's 
            <a href="http://www.kennaquhair.com/MCUControlPlus/ target="_blank">MCU Control Plus</a>
        - get and put PEC tables from/to LittleFoot
        - communication with LittleFoot via serial line basically works

    \section v01 Aspect 0.1 (02 Jan 2007)

    - initial release:
        - read and write PEC tables from/to .csv files
        - read PE output from
            <a href="http://www.astrosurf.org/buil/iris/lecon24_us.htm" target="_blank">IRIS</a>
        - edit and chart PE and PEC

*/